@@ -12,18 +12,16 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
+import json
 import operator
 
 from oslo_config import cfg
 from oslo_log import log
-from oslo_serialization import jsonutils
 from oslo_utils import fnmatch
 from oslo_utils import timeutils
 import six
 
 from aodh import evaluator
-from aodh.i18n import _
 
 LOG = log.getLogger(__name__)
 
@@ -249,12 +247,12 @@ class EventAlarmEvaluator(evaluator.Evaluator):
         """Update alarm state and fire alarm via alarm notifier."""
 
         state = evaluator.ALARM
-        reason = (_('Event <id=%(id)s,event_type=%(event_type)s> hits the '
-                    'query <query=%(alarm_query)s>.') %
+        reason = (('Event <id=%(id)s,event_type=%(event_type)s> hits the '
+                   'query <query=%(alarm_query)s>.') %
                   {'id': event.id,
                    'event_type': event.get_value('event_type'),
-                   'alarm_query': jsonutils.dumps(alarm.obj.rule['query'],
-                                                  sort_keys=True)})
+                   'alarm_query': json.dumps(alarm.obj.rule['query'],
+                                             sort_keys=True)})
         reason_data = {'type': 'event', 'event': event.obj}
         always_record = alarm.obj.repeat_actions
         self._refresh(alarm.obj, state, reason, reason_data, always_record)
